<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Ana Pencere</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Yazılım (xrandr) Parlaklığı</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>Metin Etiketi</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Donanım Arka Işığı</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX-İnce Ayar</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Görüntü</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="57"/>
        <location filename="../defaultlook.cpp" line="78"/>
        <location filename="../defaultlook.cpp" line="629"/>
        <location filename="../defaultlook.cpp" line="648"/>
        <location filename="../defaultlook.cpp" line="657"/>
        <location filename="../defaultlook.cpp" line="699"/>
        <location filename="../defaultlook.cpp" line="709"/>
        <location filename="../defaultlook.cpp" line="737"/>
        <location filename="../defaultlook.cpp" line="740"/>
        <source>MX Tweak</source>
        <translation>MX İnce ayar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="32"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Paneli özelleştirme&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="46"/>
        <location filename="../defaultlook.ui" line="156"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="66"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pencere davranışı ve kısayolları yapılandırma&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="80"/>
        <source>Window Manager</source>
        <translation>Pencere Yöneticisi</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="100"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Masaüstünüzün görünümünü özelleştirin&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="114"/>
        <source>Appearance</source>
        <translation>Görünüş</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="129"/>
        <source>Xfce Settings</source>
        <translation>Xfce Ayarları</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="320"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Tüm panelleri etkiler&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="227"/>
        <location filename="../defaultlook.ui" line="1452"/>
        <source>Affects 1st panel</source>
        <translation>1. paneli etkiler</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="280"/>
        <location filename="../defaultlook.ui" line="1475"/>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="285"/>
        <location filename="../defaultlook.ui" line="1485"/>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="204"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pencere Düğmeleri&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="254"/>
        <location filename="../defaultlook.ui" line="1470"/>
        <source>Bottom</source>
        <translation>En alt</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="259"/>
        <location filename="../defaultlook.ui" line="1480"/>
        <source>Top</source>
        <translation>En üst</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="234"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="164"/>
        <location filename="../defaultlook.ui" line="303"/>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="310"/>
        <source>Display panel horizontally</source>
        <translation>Paneli yatay olarak göster</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="171"/>
        <source>Display panel vertically</source>
        <translation>Paneli dikey olarak göster</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="211"/>
        <source>Restore default panel</source>
        <translation>Öntanımlı panele geri dön</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="181"/>
        <source>Backup current panel configuration</source>
        <translation>Şimdiki panel yapılandırmasını yedekle</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Restore backup panel configuration</source>
        <translation>Yedek panel yapılandırmasını geri yükle</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="353"/>
        <location filename="../defaultlook.ui" line="405"/>
        <location filename="../defaultlook.ui" line="561"/>
        <location filename="../defaultlook.ui" line="886"/>
        <location filename="../defaultlook.ui" line="893"/>
        <location filename="../defaultlook.ui" line="900"/>
        <location filename="../defaultlook.ui" line="1016"/>
        <location filename="../defaultlook.ui" line="1417"/>
        <location filename="../defaultlook.ui" line="1610"/>
        <location filename="../defaultlook.ui" line="1766"/>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="384"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="392"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Simgeler&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="428"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Koyu temada HexChat giriş kutusunu düzelt</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="435"/>
        <source>Preview</source>
        <translation>Önizleme</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="442"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Koyu tema kullanırken bazı website alanlarını düzelt</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="445"/>
        <source>Firefox dark theme tweak</source>
        <translation>Firefox koyu tema ince ayarı</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="452"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pencere Yöneticisi&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="459"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Temalar&lt;/span&gt;&lt;p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="466"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Uygulama&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="486"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Mevcut Ayarları Tema Olarak Kaydet</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="497"/>
        <source>Remove User Theme Set</source>
        <translation>Kullanıcı Temasını Kaldır</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="514"/>
        <source>Theme Options</source>
        <translation>Tema Seçenekleri</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="537"/>
        <source>Undo</source>
        <translation>Gerial</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="547"/>
        <location filename="../defaultlook.ui" line="588"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="581"/>
        <source>Transparency and shadow options</source>
        <translation>Saydamlık ve gölge seçenekleri</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="595"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>compton.conf dosyasını doğrudan metin düzenleyicide düzenleyin</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="598"/>
        <source>Edit compton.conf</source>
        <translation>compton.conf&apos;u düzenle</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="648"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;VBlank kipini değiştirmek, bazı ekran yırtılma sorunlarını hafifletmeye yardımcı olabilir. Daha fazla bilgi için Yardım&apos;a bakın.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="651"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="659"/>
        <source>auto</source>
        <translation>oto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="664"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="669"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="674"/>
        <source>off</source>
        <translation>kapalı</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="695"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="700"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="705"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="713"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Ayarları&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="716"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm Ayarları</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="727"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>compton-conf yapılandırma aracını başlat</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="730"/>
        <source>Compton settings</source>
        <translation>Compton ayarları</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="744"/>
        <source>Display</source>
        <translation>Görüntü</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="752"/>
        <source>Hardware Backlight</source>
        <translation>Donanım Arka Işığı</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="759"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;İnce Ayarı Göster&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="786"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Xrandr ince ayarları için Görüntüleme Seçimi</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="796"/>
        <source>Resolution</source>
        <translation>Çözünürlük</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="803"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ekran başına kazanç&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="806"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="813"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Yazılım (xrandr) Parlaklığı</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="820"/>
        <location filename="../defaultlook.ui" line="917"/>
        <source>TextLabel</source>
        <translation>Metin Etiketi</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="827"/>
        <source>GTK scaling</source>
        <translation>GTK ölçeği</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="847"/>
        <source>xrandr Scaling</source>
        <translation>xrandr Ölçekleme</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="943"/>
        <source>Config Options</source>
        <translation>Yapılandırma Seçenekleri</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1047"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Thunar özel sağ tıklama eylemlerini sistem varsayılanlarına sıfırlama</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="996"/>
        <source>Enable single-click on desktop</source>
        <translation>Masaüstünde tek tık etkin</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="951"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Thunar Dosya Yöneticisinde tek tık etkin</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1054"/>
        <source>Enable Desktop Zoom </source>
        <translation>Masaüstü Yakınlaştırmayı Etkinleştir </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="975"/>
        <location filename="../defaultlook.ui" line="1570"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Tüm çalışma alanlarındaki pencereleri panelde göster.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1003"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Masaüstünde uzun dosya adlarının kısaltılmasını devre dışı bırak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="989"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Oturumu Kapat menüsünde hazırda bekletme kipini etkinleştir</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="968"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   not: uyku için, takas &gt;= RAM olması gereklidir.</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1027"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>İletişim kutularının altında GTK Dosya İletişim Kutusu eylem düğmelerini göster</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="958"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="982"/>
        <source>Thunar windows always open in split view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1061"/>
        <source>Thunar split view opens horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1071"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1079"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Araç Çubuğu Ayarları&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1113"/>
        <location filename="../defaultlook.ui" line="1149"/>
        <source>On</source>
        <translation>Aç</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1118"/>
        <location filename="../defaultlook.ui" line="1154"/>
        <source>Off</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1123"/>
        <source>On Hover</source>
        <translation>Vurgulu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1141"/>
        <location filename="../defaultlook.ui" line="1162"/>
        <source>Autohide</source>
        <translation>Otomatik gizleme</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1169"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>TÜM mx-fluxbox ayarlarını sıfırla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1176"/>
        <location filename="../defaultlook.ui" line="1190"/>
        <location filename="../defaultlook.ui" line="1459"/>
        <source>Placement</source>
        <translation>Yerleştirme</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1183"/>
        <source>Reset DefaultDock</source>
        <translation>Öntanımlı Sabitleyiciyi Sıfırla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1197"/>
        <source>Toggle desktop icons</source>
        <translation>Masaüstü simgelerini değiştir</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1204"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Fluxbox Menüyü Sıfırla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1345"/>
        <location filename="../defaultlook.ui" line="1577"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Öntanımlıları Sıfırla&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1352"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Panel Ayarları&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1359"/>
        <source>Width</source>
        <translation>Genişlik</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1366"/>
        <source>Toggle icon captions</source>
        <translation>Simge altyazılarını değiştir</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1373"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Masaüstü Simgeleri&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1380"/>
        <source>Height</source>
        <translation>Yükseklik</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1387"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Varsa, mevcut fluxbox menüsüne yeni varsayılan menü öğeleri ekleyin.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1390"/>
        <source>Upgrade existing menu entries</source>
        <translation>Mevcut menü girişlerini güncelle</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1410"/>
        <source>Show Toolbar</source>
        <translation>Araç Çubuğunu Göster</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1438"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1493"/>
        <source>Systray Icon Size</source>
        <translation>Sistem Çekmecesi Simge Boyutu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1504"/>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1509"/>
        <source>Small</source>
        <translation>Küçük</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1514"/>
        <source>Medium</source>
        <translation>Orta</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1519"/>
        <source>Large</source>
        <translation>Büyük</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1524"/>
        <source>Larger</source>
        <translation>Daha Büyük</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1529"/>
        <source>Largest</source>
        <translation>En Büyük</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1556"/>
        <source>Workspace</source>
        <translation>Çalışma Alanı</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1563"/>
        <source>Enable single-click</source>
        <translation>Tek tıklamayı etkinleştir</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1584"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>KDE/Plasma öntanımlılarını sıfırla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1624"/>
        <source>Other</source>
        <translation>Diğer</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1691"/>
        <source>Password for administrative tasks:</source>
        <translation>Yönetici görevleri için parola:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1639"/>
        <source>Use tearfree radeon driver option</source>
        <translation>tearfree radeon sürücü seçeneğini kullan</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1653"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>NOTE: mevcut  /etc/X11/xorg.conf.d/20-radeon.conf ev klasörüne yedeklenecek</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1698"/>
        <source>&amp;User</source>
        <translation>Kullanıcı</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1705"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Öntanımlı &quot;modesetting&quot; sürücü yerine intel sürücüsü kullanın (yeniden başlatma gerekir)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1753"/>
        <source>Enable kernel sandbox</source>
        <translation>Çekirdek sanal alanını etkinleştir</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1677"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>NOTE: mevcut /etc/X11/xorg.conf.d/20-intel.conf ev klasörüne yedeklenecek</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1719"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Lightdm&apos;yi (giriş ekranı) sistem öntanımlı temasına sıfırla</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1684"/>
        <source>Use libinput driver for touchpad instead of synaptics touchpad driver (requires restart)</source>
        <translation>Dokunmatik yüzey için synaptics dokunmatik yüzey sürücüsü yerine libinput sürücüsünü kullanın (yeniden başlatma gerektirir)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1646"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>NOTE: mevcut /etc/X11/xorg.conf.d/20-amd.conf ev klasörüne yedeklenecek</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1632"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Dahili sürücülerin root olmayan kullanıcılar tarafından bağlanmasını etkinleştir</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1712"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Amd  grafik işlemcinin tearfree seçeneğini kullan</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1726"/>
        <source>Root</source>
        <translation>Kök</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1660"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Onları destekleyen GTK3 uygulamalarında İstemci Tarafı Dekorasyonlarını (CSD) kullanın (oturumun yeniden başlatılmasını gerektirir)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1424"/>
        <source>Manage Tint2 Panel</source>
        <translation>Tint2 Panelini Yönet</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1667"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;yeniden başlatılmalı&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1670"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation>Önyükleme sırasında Bluetooth Adaptörlerini etkinleştirin</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1777"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt, bağımlılık olarak &quot;önerilen&quot; ek paketleri kurar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1846"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1857"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1874"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1877"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1884"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="58"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--ekran anahtarı yalnızca Xfce için geçerlidir</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="628"/>
        <source>About MX Tweak</source>
        <translation>MX Tweak Hakkında</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="630"/>
        <source>Version: </source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="631"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Hızlı öntanımlı kullanıcı arayüzü tema değişiklikleri ve ince ayarlar için uygulama</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="633"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="634"/>
        <source>%1 License</source>
        <translation>%1 Ruhsat</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="648"/>
        <source>%1 Help</source>
        <translation>%1 Yardım</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="658"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Tamamlandı! Değişikliklerin etkili olması için Firefox&apos;un yeniden başlatılması gerekebilir</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="700"/>
        <source>Plese remove special characters</source>
        <translation>Lütfen özel karakterleri silin</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="700"/>
        <source>from file name</source>
        <translation>dosya adından</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="710"/>
        <source>File name already exists.  Choose another name</source>
        <translation>Dosya adı zaten var. Başka bir ad seç</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="738"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>Dosya geçerli bir tar.xz arşiv dosyası değil</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="741"/>
        <source>Archive does not contain a panel config</source>
        <translation>Arşiv, panel yapılandırması içermiyor</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="861"/>
        <source>Panel settings</source>
        <translation>Panel ayarları</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="862"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Geçerli panel ayarlarınız, ev klasörünüzde .restore adlı gizli bir klasöre yedeklendi (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1563"/>
        <source>settings</source>
        <translation>ayarlar</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1903"/>
        <source>Choose a theme set</source>
        <translation>Bir Tema Grubu Seç</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Kullanıcı Temasını Kaldır</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Yeni Tema Takımı</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Yeni tema grubu için isim girin</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Pencere Düğmeleri</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Görünüm&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Düğme etiketlerini göster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Düz düğmeleri göster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Tanıtıcıyı göster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Sıralama düzeni:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Zaman Damgası</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Grup başlığı ve zaman damgası</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Pencere başlığı</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Grup başlığı ve pencere başlığı</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Hiçbiri, sürükle-bıraka izin ver</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Davranış&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Pencere gruplama:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Asla</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Daima</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Orta tıklama eylemi:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Pencereyi Kapat</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Pencereyi Küçült</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Küçültülmüş pencereyi mevcut çalışma alanına geri yükle</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Herhangi bir düğme üzerindeyken pencere çerçevesini çiz</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Pencereler arasında fare topu kullanarak geçiş yap</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtreleme&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Tüm çalışma alanlarındaki bütün pencereleri göster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Sadece küçültülmüş pencereleri göster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Tüm monitörlerdeki bütün pencereleri göster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Açılır Pencereler</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Hareket halinde pencereler</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Matlık Ayarları&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Pencere döşemeleri</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Sabit pencerlerin altında gölgeler göster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Açılır pencerelerin altında gölgeler göster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Yeniden boyutlandırma sırasında pencereler</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Normal pencerelerin altında gölge göster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Özellik Ayarları&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Döngü sırasında simgelerin yerine pencere önizlemesini göster</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Tüm ekranı kaplayan pencereyi doğrudan görüntüle</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Etkin olmayan pencereler</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Çizimi dikey boşluğa eşzamanla</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Xfwm Compositor Ayarları</translation>
    </message>
</context>
</TS>
